<?php

namespace Drp\UserManagement\Http\Controllers\Admin;

use Drp\UserManagement\Contracts\ManagedUser;
use Drp\UserManagement\Http\Requests\CreateUser;
use Drp\UserManagement\UserCreator;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Routing\Controller;

/**
 * Class UsersController
 * @package App\Http\Controllers\Admin
 */
class UsersController extends Controller
{
    use AuthorizesRequests, DispatchesJobs, ValidatesRequests;

    /**
     * @var ManagedUser
     */
    private $user;

    /**
     * UsersController constructor.
     * @param ManagedUser $user
     */
    public function __construct(ManagedUser $user)
    {
        $this->user = $user;
    }

    /**
     * Display a listing of the users.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $users = $this->user->get();
        $awaitingApproval = $this->user->allAwaitingApproval();
        return view('userManagement::users.index', compact('users', 'awaitingApproval'));
    }

    /**
     * Show the form for creating a new user.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('userManagement::users.create');
    }

    /**
     * Store a newly created user in storage.
     *
     * @param  CreateUser $request
     * @param UserCreator $userCreator
     * @return \Illuminate\Http\Response
     */
    public function store(
        CreateUser $request,
        UserCreator $userCreator
    ) {
        $userCreator->createWithLoginCode($request->all());

        flash()->success(trans('userManagement::users.created'));

        return redirect()
            ->route('admin.users.index');
    }

    /**
     * Show the form for editing the specified user.
     *
     * @param ManagedUser $user
     * @return \Illuminate\Http\Response
     */
    public function edit(ManagedUser $user)
    {
        return view('userManagement::users.edit', compact('user'));
    }

    /**
     * Update the specified user in storage.
     *
     * @param CreateUser $request
     * @param ManagedUser $user
     * @return \Illuminate\Http\Response
     */
    public function update(CreateUser $request, ManagedUser $user)
    {
        $user->update($request->all());

        flash()->success(trans('userManagement::users.updated'));

        return redirect()
            ->route('admin.users.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param ManagedUser $user
     * @return \Illuminate\Http\Response
     */
    public function destroy(ManagedUser $user)
    {
        $this->authorize('delete', $user);

        $user->delete();

        flash()->success(trans('userManagement::users.deleted'));

        return redirect()
            ->route('admin.users.index');
    }
}
