<?php

namespace Drp\UserManagement\Http\Controllers\Auth;

use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;

/**
 * Class AccountSetupController
 * @package App\Http\Controllers
 */
class AccountSetupController extends Controller
{

    use ResetsPasswords, AuthorizesRequests, ValidatesRequests;

    /**
     * Show the initial setup form
     * @param Request $request
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request)
    {
        //Check if the password has already been setup
        $user = $request->user();

        if (!empty($user->password)) {
            return redirect()->route(config('user_management.admin-route'));
        }

        return view('userManagement::auth.setup');
    }

    /**
     * @param Request $request
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function update(Request $request)
    {
        $this->validate(
            $request,
            ['password' => 'required|confirmed|min:6']
        );

        $this->resetPassword($request->user(), $request->get('password'));

        $request->user()->removeFirstLoginToken();

        flash()->success(trans('userManagement::users.setup'));
        return redirect()
            ->route(config('user_management.admin-route'));
    }
}
